==> ulyxex.0.0.4.with-tinyMce.zip: pages/code/admin_page_modify.php <==
<?php
class PageModify extends Admin {
	public function cat_params($id) {
		$req = "SELECT * FROM ".PAGES." WHERE ID=".$id;
		$req = $this->req($req);
		$result = mysql_fetch_assoc($req);
		return $result;
	}
	public function userPages() {
		$siteDat = $this->home_params();
		$reqLevel2 = 	"SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES.",".USERPAGES.
						" WHERE ".USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID ORDER BY ".PAGES.".NAME";
						
		$reqLevel1 = 	"SELECT ID,NAME FROM ".PAGES." ORDER BY NAME";
		
		if ($_SESSION['level'] > 1) {
			$req = $this->req($reqLevel2);
		} else {
			$req = $this->req($reqLevel1);
		}
		$elements = array();
		while ( $line = mysql_fetch_assoc($req) ) {
			if ($line['ID'] == $siteDat['PAGEID']) {
				$elements[$line['NAME']." (home)"] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		if (count($elements)) {
			$h = New Html();
			$menu = $h->select($elements,"cat",$siteDat['PAGEID']).$h->input("submit",null,"GO");
			$result = $h->form("modify ".$menu,"pages","post","admin.php?action=modify_page");
			return $result;
		}
	}
	public function update_page($catId) {
		$h = New Html();
		$hide = (isset($_POST['hide']))?1:0;
		$req = "UPDATE ".PAGES." SET NAME = '".$h->safe($_POST['name'])."',".
									"DESCRIPTION = '".$h->safe($_POST['description'])."',".
									"HIDE = '".$hide."'".
									" WHERE ID = ".$catId;
		$req = $this->req($req);
		$result = $h->h3("page updated !");
		return $result;
	}
	public function data_page($catId) {
		$h = New Html();
		$reqLevel1 = 	"SELECT ".PAGES.".* FROM ".PAGES." WHERE ID = ".$catId;
		$reqLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
						USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID"." AND ".
						PAGES.".ID = ".$catId;

		if ($_SESSION['level'] > 1) {
			$req = $this->req($reqLevel2);
		} else {
			$req = $this->req($reqLevel1);
		}
		if ($req) {
			$dat = mysql_fetch_assoc($req);
			$content = $h->input("hidden","cat",$dat['ID']);
			$content .= $h->input("hidden","update",1);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $h->p("hide ".$h->input("checkbox","hide","on",$params));
			$content .= $h->p("name").$h->p($h->input("text","name",$dat['NAME'],"size=".FIELDWIDTH));
			$content .= $h->p("description").$h->p($h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
			$content .= $h->p($h->input("submit","save","update"));
			$result = $h->form($content,"page","post","admin.php?action=modify_page");
			return $result;
		}
	}
}
?>

==> ulyxex.0.0.5.with-tinyMce.zip: pages/code/admin_page_modify.php <==
<?php
class PageModify extends Admin {
	public function cat_params($id) {
		$query = "SELECT * FROM ".PAGES." WHERE ID=".$id;
		$query = $this->q($query);
		$result = mysql_fetch_assoc($query);
		return $result;
	}
	public function userPages() {
		$siteDat = $this->home_params();
		$queryLevel2 = 	"SELECT ".PAGES.".ID,".PAGES.".NAME FROM ".PAGES.",".USERPAGES.
						" WHERE ".USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID ORDER BY ".PAGES.".NAME";
						
		$queryLevel1 = 	"SELECT ID,NAME FROM ".PAGES." ORDER BY NAME";
		
		if ($_SESSION['level'] > 1) {
			$query = $this->q($queryLevel2);
		} else {
			$query = $this->q($queryLevel1);
		}
		$elements = array();
		while ( $line = mysql_fetch_assoc($query) ) {
			if ($line['ID'] == $siteDat['PAGEID']) {
				$elements[$line['NAME']." (home)"] = $line['ID'];
			} else {
				$elements[$line['NAME']] = $line['ID'];
			}
		}
		if (count($elements)) {
			$h = New Html();
			$menu = $h->select($elements,"cat",$siteDat['PAGEID'])." ".$h->input("submit",null,"GO");
			$result = $h->form("modify ".$menu,"pages","post","admin.php?action=modify_page");
			return $result;
		}
	}
	public function update_page($catId) {
		$h = New Html();
		$hide = (isset($_POST['hide']))?1:0;
		$query = "UPDATE ".PAGES." SET NAME = '".$h->safe($_POST['name'])."',".
									"DESCRIPTION = '".$h->safe($_POST['description'])."',".
									"HIDE = '".$hide."'".
									" WHERE ID = ".$catId;
		$query = $this->q($query);
		$result = $h->h3("page updated !");
		return $result;
	}
	public function data_page($catId) {
		$h = New Html();
		$queryLevel1 = 	"SELECT ".PAGES.".* FROM ".PAGES." WHERE ID = ".$catId;
		$queryLevel2 = 	"SELECT ".PAGES.".* FROM ".PAGES.",".USERPAGES." WHERE ".
						USERPAGES.".USERID = ".$_SESSION['userid']." AND ".
						USERPAGES.".PAGEID = ".PAGES.".ID"." AND ".
						PAGES.".ID = ".$catId;

		if ($_SESSION['level'] > 1) {
			$query = $this->q($queryLevel2);
		} else {
			$query = $this->q($queryLevel1);
		}
		if ($query) {
			$dat = mysql_fetch_assoc($query);
			$sandboxParams = "";
			if ($dat['NAME'] == "SANDBOX") {
				$sandboxParams = "readonly";
			}
			$content = $h->input("hidden","cat",$dat['ID']);
			$content .= $h->input("hidden","update",1);
			$params =  ($dat['HIDE'])?" checked=\"checked\"":null;
			$content .= $h->p("hide ".$h->input("checkbox","hide","on",$params));
			$content .= $h->p("name").$h->p($h->input("text","name",$dat['NAME'],$sandboxParams." size=".FIELDWIDTH));
			$content .= $h->p("description").$h->p($h->textarea($dat['DESCRIPTION'],"description",array(8,FIELDWIDTH)));
			$content .= $h->p($h->input("submit","save","update"));
			$result = $h->form($content,"page","post","admin.php?action=modify_page");
			return $result;
		}
	}
}
?>
